@@ -10,7 +10,7 @@ use Template::Flute::Utils;
 # names for the sides of a box, as in border-top, border-right, ...
 use constant SIDE_NAMES => qw/top right bottom left/;
 
-our $VERSION = '0.0002';
+our $VERSION = '0.0003';
 
 =head1 NAME
 
@@ -18,7 +18,7 @@ Template::Flute::Style::CSS - CSS parser class for Template::Flute
 
 =head1 VERSION
 
-Version 0.0002
+Version 0.0003
 
 =head1 CONSTRUCTOR
 
@@ -127,6 +127,10 @@ sub properties {
 	# defaults
 	$props->{color} = 'black';
 
+	if (defined $parms{tag} && $parms{tag} =~ /\S/) {
+		@tags = split(/\s+/, $parms{tag});
+	}
+	
 	if (defined $parms{id} && $parms{id} =~ /\S/) {
 		@ids = split(/\s+/, $parms{id});
 
@@ -140,12 +144,13 @@ sub properties {
 
 		for my $class (@classes) {
 			$self->_build_properties($props, ".$class");
+			for (@tags) {
+				$self->_build_properties($props, "$_.$class");
+			}
 		}
 	}
 
-	if (defined $parms{tag} && $parms{tag} =~ /\S/) {
-		@tags = split(/\s+/, $parms{tag});
-			
+	if (@tags) {
 		for my $tag (@tags) {
 			$self->_build_properties($props, $tag);
 
